@@ -11,9 +11,10 @@ from textwrap import dedent
 from copy import deepcopy
 import warnings
 import re
+import logging
 
 from sumatra.programs import get_executable
-from sumatra.datastore import FileSystemDataStore, ArchivingFileSystemDataStore
+from sumatra.datastore import FileSystemDataStore, ArchivingFileSystemDataStore, MirroredFileSystemDataStore
 from sumatra.projects import Project, load_project
 from sumatra.launch import SerialLaunchMode, DistributedLaunchMode
 from sumatra.parameters import build_parameters
@@ -23,6 +24,16 @@ from sumatra.formatting import get_diff_formatter
 from sumatra.records import MissingInformationError
 from sumatra.core import TIMESTAMP_FORMAT
 
+logger = logging.getLogger("Sumatra")
+logger.setLevel(logging.CRITICAL)
+h = logging.StreamHandler()
+h.setFormatter(logging.Formatter('%(asctime)s - %(levelname)s - %(message)s'))
+logger.addHandler(h)
+
+logger.debug("STARTING")
+
+modes = ("init", "configure", "info", "run", "list", "delete", "comment", "tag",
+         "repeat", "diff", "help", "export", "upgrade", "sync")
 
 def parse_executable_str(exec_str):
     """
@@ -102,8 +113,10 @@ def init(argv):
     parser.add_option('-m', '--main', help="the name of the script that would be supplied on the command line if running the simulation or analysis normally, e.g. init.hoc.")
     parser.add_option('-c', '--on-changed', default='error', help="the action to take if the code in the repository or any of the depdendencies has changed. Defaults to %default") # need to add list of allowed values
     parser.add_option('-s', '--store', help="specify the path to the record store, either an existing one or one to be created.")
-    parser.add_option('-D', '--debug', action='store_true', help="print debugging information.")
     parser.add_option('-A', '--archive', metavar='PATH', help="specify a directory in which to archive output datafiles. If not specified, datafiles are not archived.")
+    parser.add_option('-g', '--labelgenerator', choices=['timestamp', 'uuid'], default='timestamp', metavar='OPTION', help="specify which method Sumatra should use to generate labels (options: timestamp, uuid)")
+    parser.add_option('-t', '--timestamp_format', help="the timestamp format given to strftime", default=TIMESTAMP_FORMAT)
+    parser.add_option('-M', '--mirror', metavar='URL', help="specify a URL at which your datafiles will be mirrored.")
 
     (options, args) = parser.parse_args(argv)
 
@@ -117,9 +130,6 @@ def init(argv):
         parser.error('You must supply a name.')
     project_name = args[0]
 
-    global _debug
-    _debug = options.debug
-
     if not os.path.exists(".smt"):
         os.mkdir(".smt")
 
@@ -146,11 +156,15 @@ def init(argv):
     else:
         record_store = 'default'
 
+    if options.archive and options.mirror:
+        raise Exception("Currently, it is not possible to specify both --archive and --mirror options")
     if options.archive and options.archive.lower() != 'false':
         if options.archive.lower() == "true":
             options.archive = ".smt/archive"
         options.archive = os.path.abspath(options.archive)
         output_datastore = ArchivingFileSystemDataStore(options.datapath, options.archive)
+    elif options.mirror:
+        output_datastore = MirroredFileSystemDataStore(options.datapath, options.mirror)
     else:
         output_datastore = FileSystemDataStore(options.datapath)
     input_datastore = FileSystemDataStore(options.input)
@@ -164,7 +178,9 @@ def init(argv):
                       record_store=record_store,
                       on_changed=options.on_changed,
                       data_label=options.addlabel,
-                      input_datastore=input_datastore)
+                      input_datastore=input_datastore,
+                      label_generator=options.labelgenerator,
+                      timestamp_format=options.timestamp_format)
     project.save()
 
 def configure(argv):
@@ -182,7 +198,9 @@ def configure(argv):
     parser.add_option('-m', '--main', help="the name of the script that would be supplied on the command line if running the simulator normally, e.g. init.hoc.")
     parser.add_option('-c', '--on-changed', help="may be 'store-diff' or 'error': the action to take if the code in the repository or any of the dependencies has changed. Defaults to 'error'", choices=['store-diff', 'error'])
     parser.add_option('-A', '--archive', metavar='PATH', help="specify a directory in which to archive output datafiles. If not specified, or if 'false', datafiles are not archived.")
-
+    parser.add_option('-g', '--labelgenerator', choices=['timestamp', 'uuid'], metavar='OPTION', help="specify which method Sumatra should use to generate labels (options: timestamp, uuid)")
+    parser.add_option('-t', '--timestamp_format', help="the timestamp format given to strftime")
+    
     (options, args) = parser.parse_args(argv)
     if len(args) != 0:
         parser.error('configure does not take any arguments')
@@ -217,6 +235,10 @@ def configure(argv):
         project.on_changed = options.on_changed
     if options.addlabel:
         project.data_label = options.addlabel
+    if options.labelgenerator:
+        project.label_generator = options.labelgenerator
+    if options.timestamp_format:
+        project.timestamp_format = options.timestamp_format
     project.save()
 
 
@@ -264,9 +286,13 @@ def run(argv):
     parser.add_option('-n', '--num_processes', metavar='N', type="int",
                       help="run a distributed computation on N processes using MPI. If this option is not used, or if N=0, a normal, serial simulation/analysis is run.")
     parser.add_option('-t', '--tag', help="tag you want to add to the project")
+    parser.add_option('-D', '--debug', action='store_true', help="print debugging information.")
 
     (options, args) = parser.parse_args(argv)
 
+    if options.debug:
+        logger.setLevel(logging.DEBUG)
+
     project = load_project()
     parameters, input_data, script_args = parse_arguments(args, project.input_datastore)
     if len(parameters) == 0:
@@ -367,9 +393,9 @@ def comment(argv):
     usage = "%prog comment [options] [LABEL] [COMMENT]"
     description = dedent("""\
       This command is used to describe the outcome of the simulation/analysis. If LABEL
-      is omitted, the comment will be added to the most recent experiment.
-      If the '-f/--file' option is set, COMMENT should be the name of a file
-      containing the comment, otherwise it should be a string of text.""")
+      is omitted, the comment will be added to the most recent experiment (any existing
+      comment will be overwritten). If the '-f/--file' option is set, COMMENT should be
+      the name of a file containing the comment, otherwise it should be a string of text.""")
     parser = OptionParser(usage=usage,
                           description=description)
     parser.add_option('-r', '--replace', action='store_true',
@@ -494,7 +520,7 @@ def help(argv):
                           description=description)
     (options, args) = parser.parse_args(argv)
     if len(args) != 1:
-        parser.error('Please specify a command on which you would like help.')
+        parser.error('Please specify a command on which you would like help.\n\nAvailable commands:\n  ' + "\n  ".join(modes))
     cmd = args[0]
     try:
         func = globals()[cmd]
@@ -541,14 +567,8 @@ def export(argv):
     (options, args) = parser.parse_args(argv)
     if len(args) != 0:
         parser.error('%prog export does not take any arguments.')
-    # copy the project data
-    import shutil
-    shutil.copy(".smt/project", ".smt/project_export.json")
-    # export the record data
     project = load_project()
-    f = open(".smt/records_export.json", 'w')
-    f.write(project.record_store.export(project.name))
-    f.close()
+    project.export()
 
 def sync(argv):
     usage = "%prog sync PATH1 [PATH2]"
