@@ -37,10 +37,12 @@ import sys
 from modulefinder import Module
 import warnings
 import inspect
+import logging
 
 from sumatra.dependency_finder import core
 from sumatra import versioncontrol
 
+logger = logging.getLogger("Sumatra")
 SENTINEL = "<SUMATRA>"
 
 
@@ -61,7 +63,6 @@ def run_script(executable_path, script):
         return_value = eval(output)
     except SyntaxError, errmsg:
         warnings.warn("Error in evaluating script output\n. Executable: %s\nScript: %s\nOutput: '%s'\nError: %s" % (executable_path, script, output, err))
-        #import pdb; pdb.set_trace()
         return_value = {}
     return return_value
 
@@ -69,7 +70,7 @@ def run_script(executable_path, script):
 def find_version_by_attribute(module):
     from types import ModuleType
     version = 'unknown'
-    for attr_name in 'version', 'get_version', '__version__', 'VERSION':
+    for attr_name in '__version__', 'version', 'get_version', 'VERSION', 'Version':
         if hasattr(module, attr_name):
             attr = getattr(module, attr_name)
             if callable(attr):
@@ -119,6 +120,8 @@ def find_versions_by_attribute(dependencies, executable):
     for d in dependencies:
         if d.version == 'unknown':
             d.version = versions[i]
+            if d.version != 'unknown':
+                d.source = "attribute"  # would be nice to pass back the attribute name
             i += 1
     return dependencies
 
@@ -135,7 +138,7 @@ def find_versions_from_egg(dependencies):
                         for line in f.readlines():
                             if line[:7] == 'Version':
                                 dependency.version = line.split(' ')[1].strip()
-                                attr_name = 'egg-info'
+                                dependency.source = 'egg-info'
                                 break
     return dependencies
 
@@ -147,7 +150,6 @@ def find_versions_from_egg(dependencies):
 #   * could also look in the __init__.py for a Subversion $Id:$ tag
 
 
-
 class Dependency(core.BaseDependency):
     """
     Contains information about a Python module or package, and tries to
@@ -155,11 +157,8 @@ class Dependency(core.BaseDependency):
     """
     module = 'python'
 
-    def __init__(self, module_name, path, version='unknown', diff=''):
-        self.name = module_name
-        self.path = path
-        self.diff = diff
-        self.version = version
+    def __init__(self, module_name, path, version='unknown', diff='', source=None):
+        super(Dependency, self).__init__(module_name, path, version, diff, source)
 
     @classmethod
     def from_module(cls, module, executable_path):
@@ -207,8 +206,10 @@ def find_dependencies(filename, executable):
     heuristics = [core.find_versions_from_versioncontrol,
                   lambda deps: find_versions_by_attribute(deps, executable),
                   find_versions_from_egg]
+    logger.debug("Finding imported packages")
     packages = find_imported_packages(filename, executable.path, exclude_stdlib=True)
     dependencies = [Dependency.from_module(module, executable.path) for module in packages.values()]
+    logger.debug("Finding versions of dependencies")
     return core.find_versions(dependencies, heuristics)
 
 
