@@ -22,19 +22,29 @@ import os
 import sys
 import cPickle as pickle
 from copy import deepcopy
+import uuid
 from sumatra.records import Record
 from sumatra import programs, datastore
 from sumatra.formatting import get_formatter, get_diff_formatter
 from sumatra.recordstore import DefaultRecordStore
 from sumatra.versioncontrol import UncommittedModificationsError, get_working_copy
+from sumatra.core import TIMESTAMP_FORMAT
 import mimetypes
 try:
     import json
 except ImportError:
     import simplejson as json
+import logging
+
+logger = logging.getLogger("Sumatra")
 
 DEFAULT_PROJECT_FILE = "project"
 
+LABEL_GENERATORS = {
+    'timestamp': lambda: None, # this is the default, implemented in the Record class
+    'uuid': lambda: str(uuid.uuid4()).split('-')[-1]
+}
+
 
 def _remove_left_margin(s): # replace this by textwrap.dedent?
     lines = s.strip().split('\n')
@@ -50,7 +60,8 @@ class Project(object):
                  default_main_file=None, default_launch_mode=None,
                  data_store='default', record_store='default',
                  on_changed='error', description='', data_label=None,
-                 input_datastore=None):
+                 input_datastore=None, label_generator='timestamp',
+                 timestamp_format=TIMESTAMP_FORMAT):
         self.path = os.getcwd()
         if not os.path.exists(".smt"):
             os.mkdir(".smt")
@@ -71,7 +82,9 @@ class Project(object):
         self.on_changed = on_changed
         self.description = description
         self.data_label = data_label
-        self._most_recent = None
+        self.label_generator = label_generator
+        self.timestamp_format = timestamp_format        
+        self._most_recent = None            
         self.save()
         print "Sumatra project successfully set up"
         
@@ -89,7 +102,8 @@ class Project(object):
         for name in ('name', 'default_executable', 'default_repository',
                      'default_launch_mode', 'data_store', 'record_store',
                      'default_main_file', 'on_changed', 'description',
-                     'data_label', '_most_recent', 'input_datastore',):
+                     'data_label', '_most_recent', 'input_datastore',
+                     'label_generator', 'timestamp_format'):
             attr = getattr(self, name, None)
             if hasattr(attr, "__getstate__"):
                 state[name] = {'type': attr.__class__.__module__ + "." + attr.__class__.__name__}
@@ -114,13 +128,16 @@ class Project(object):
         Record store        : %(record_store)s
         Code change policy  : %(on_changed)s
         Append label to     : %(_data_label)s
+        Label generator     : %(label_generator)s
+        Timestamp format    : %(timestamp_format)s
         """
         return _remove_left_margin(template % self.__dict__)
     
     def new_record(self, parameters={}, input_data=[], script_args="",
                    executable='default', repository='default',
                    main_file='default', version='latest', launch_mode='default',
-                   label=None, reason=None):
+                   label=None, reason=None, timestamp_format='default'):
+        logger.debug("Creating new record")
         if executable == 'default':
             executable = deepcopy(self.default_executable)           
         if repository == 'default':
@@ -129,24 +146,30 @@ class Project(object):
             main_file = self.default_main_file
         if launch_mode == 'default':
             launch_mode = deepcopy(self.default_launch_mode)
+        if timestamp_format == 'default':
+            timestamp_format = self.timestamp_format
         working_copy = repository.get_working_copy()
         version, diff = self.update_code(working_copy, version)
+        if label is None:
+            label = LABEL_GENERATORS[self.label_generator]()
         record = Record(executable, repository, main_file, version, launch_mode,
                         self.data_store, parameters, input_data, script_args, 
                         label=label, reason=reason, diff=diff,
                         on_changed=self.on_changed,
-                        input_datastore=self.input_datastore)
+                        input_datastore=self.input_datastore,
+                        timestamp_format=timestamp_format)
         if not isinstance(executable, programs.MatlabExecutable):
             record.register(working_copy)
         return record
     
     def launch(self, parameters={}, input_data=[], script_args="",
                executable='default', repository='default', main_file='default',
-               version='latest', launch_mode='default', label=None, reason=None):
+               version='latest', launch_mode='default', label=None, reason=None, 
+               timestamp_format='default'):
         """Launch a new simulation or analysis."""
         record = self.new_record(parameters, input_data, script_args,
                                  executable, repository, main_file, version,
-                                 launch_mode, label, reason) 
+                                 launch_mode, label, reason, timestamp_format) 
         record.run(with_label=self.data_label)
         if 'matlab' in record.executable.name.lower():
             record.register(record.repository.get_working_copy())
@@ -155,9 +178,10 @@ class Project(object):
         return record.label
     
     def update_code(self, working_copy, version='latest'):
-        # Check if the working copy has modifications and prompt to commit or revert them
+        """Check if the working copy has modifications and prompt to commit or revert them."""
         # we really need to extend this to the dependencies, but we need to take extra special care that the
         # code ends up in the same condition as before the run
+        logger.debug("Updating working copy to use version: %s" % version)
         diff = ''
         changed = working_copy.has_changed()
         if version == 'latest':
@@ -236,6 +260,16 @@ class Project(object):
         formatter = get_diff_formatter()(diff)
         return formatter.format(mode)
 
+    def export(self):
+        # copy the project data
+        import shutil
+        shutil.copy(".smt/project", ".smt/project_export.json")
+        # export the record data
+        f = open(".smt/records_export.json", 'w')
+        f.write(self.record_store.export(self.name))
+        f.close()
+        
+        
 
 def _load_project_from_json(path):
     f = open(_get_project_file(path), 'r')
