@@ -48,8 +48,7 @@ def get_repository(url):
 class BazaarWorkingCopy(WorkingCopy):
 
     def __init__(self, path=None):
-        WorkingCopy.__init__(self)
-        self.path = path or os.getcwd()
+        WorkingCopy.__init__(self, path)
         self.workingtree = WorkingTree.open(self.path)
         self.repository = BazaarRepository(self.workingtree.branch.user_url)
         #self.repository.working_copy = self
@@ -99,18 +98,26 @@ class BazaarWorkingCopy(WorkingCopy):
         # textstream
         return iostream.getvalue()
 
+    def get_username(self):
+        config = self.workingtree.branch.get_config()
+        return config.username()
+
 
 class BazaarRepository(Repository):
     
-    def __init__(self, url):
-        Repository.__init__(self, url)
+    def __init__(self, url, upstream=None):
+        Repository.__init__(self, url, upstream)
         self.url = url
         self.__repository = None
+        # use bzrlib.info.gather_location_info to get upstream?
     
     @property
     def exists(self):
-        if self._repository:
-            return True
+        try:
+            self._repository
+        except VersionControlError:
+            pass
+        return bool(self.__repository)
     
     @property
     def _repository(self):
